==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/server/dispatch/FilterFilterChain.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.server.dispatch;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import java.io.IOException;
import java.util.logging.*;

import com.caucho.servlet.comet.CometFilterChain;

/**
 * Represents the next filter in a filter chain.  The final filter will
 * be the servlet itself.
 */
public class FilterFilterChain extends AbstractFilterChain
{
  private static final Logger log
    = Logger.getLogger(FilterFilterChain.class.getName());
  
  // Next filter chain
  private FilterChain _next;
  
  // filter
  private Filter _filter;

  private boolean _isFinest;

  /**
   * Creates a new FilterChainFilter.
   *
   * @param next the next filterChain
   * @param filter the user's filter
   */
  public FilterFilterChain(FilterChain next, Filter filter)
  {
    _next = next;
    _filter = filter;

    _isFinest = log.isLoggable(Level.FINEST);
  }
  
  /**
   * Invokes the next filter in the chain or the final servlet at
   * the end of the chain.
   *
   * @param request the servlet request
   * @param response the servlet response
   * @since Servlet 2.3
   */
  public void doFilter(ServletRequest request,
                       ServletResponse response)
    throws ServletException, IOException
  {
    if (_isFinest)
      log.finest("Dispatch " + request + " filter=" + _filter + " next=" + _next);
    
    _filter.doFilter(request, response, _next);
  }
  
  /**
   * Resumes the request.
   *
   * @param request the servlet request
   * @param response the servlet response
   *
   * @since Resin 3.1.3
   */
  @Override
  public boolean doResume(ServletRequest request,
			  ServletResponse response)
    throws ServletException, IOException
  {
    if (_next instanceof CometFilterChain) {
      CometFilterChain next = (CometFilterChain) _next;

      return next.doResume(request, response);
    }
    else
      return false;
  }

  public String toString()
  {
    return getClass().getSimpleName() + "[" + _filter + "]";
  }
}

==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/resin/src/com/caucho/server/dispatch/FilterFilterChain.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.server.dispatch;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import java.io.IOException;
import java.util.logging.*;

import com.caucho.server.http.CauchoRequest;

/**
 * Represents the next filter in a filter chain.  The final filter will
 * be the servlet itself.
 */
public class FilterFilterChain implements FilterChain
{
  private static final Logger log
    = Logger.getLogger(FilterFilterChain.class.getName());

  // Next filter chain
  private FilterChain _next;

  // filter
  private Filter _filter;

  private boolean _isFinest;

  /**
   * Creates a new FilterChainFilter.
   *
   * @param next the next filterChain
   * @param filter the user's filter
   */
  public FilterFilterChain(FilterChain next,
                           Filter filter)
  {
    _next = next;
    _filter = filter;

    _isFinest = log.isLoggable(Level.FINEST);
  }

  /**
   * Invokes the next filter in the chain or the final servlet at
   * the end of the chain.
   *
   * @param request the servlet request
   * @param response the servlet response
   * @since Servlet 2.3
   */
  @Override
  public void doFilter(ServletRequest request,
                       ServletResponse response)
    throws ServletException, IOException
  {
    if (_isFinest)
      log.finest("Dispatch " + request + " filter=" + _filter + " next=" + _next);

    _filter.doFilter(request, response, _next);
  }

  @Override
  public String toString()
  {
    return getClass().getSimpleName() + "[" + _filter + ",next=" + _next + "]";
  }
}
